@@ -4,27 +4,20 @@ from typing import Dict, List
 import click
 from pygitguardian.models import Detail
 
-from .text_utils import STYLE, format_text, pluralize
+from .text_utils import STYLE, display_error, format_text, pluralize
 
 
-def handle_scan_error(detail: Detail, chunk: List[Dict[str, str]]):
+def handle_scan_error(detail: Detail, chunk: List[Dict[str, str]]) -> None:
     if detail.status_code == 401:
         raise click.UsageError(detail.detail)
 
-    click.echo(
-        format_text("Error scanning. Results may be incomplete.", STYLE["error"]),
-        err=True,
-    )
+    display_error("Error scanning. Results may be incomplete.")
     try:
         details = literal_eval(detail.detail)
         if isinstance(details, list) and details:
-            click.echo(
-                format_text(
-                    f"Add the following {pluralize('file', len(details))}"
-                    " to your paths-ignore:",
-                    STYLE["error"],
-                ),
-                err=True,
+            display_error(
+                f"Add the following {pluralize('file', len(details))}"
+                " to your paths-ignore:"
             )
         for i, inner_detail in enumerate(details):
             if inner_detail:
